// Generated by gmmproc 2.58.0 -- DO NOT MODIFY!
#ifndef _GXWMM_METERSCALE_H
#define _GXWMM_METERSCALE_H


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

/*
 * Copyright (C) 2009, 2010 Hermann Meyer, James Warden, Andreas Degert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <gtkmm/box.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
using GxMeterScale = struct _GxMeterScale;
using GxMeterScaleClass = struct _GxMeterScaleClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gxw
{ class MeterScale_Class; } // namespace Gxw
#endif //DOXYGEN_SHOULD_SKIP_THIS

namespace Gxw {

/** @addtogroup gxwmmEnums gxwmm Enums and Flags */

/** 
 *
 * @ingroup gxwmmEnums
 */
enum TickPosition
{
  TICK_LEFT,
  TICK_RIGHT,
  TICK_BOTH,
  TICK_BELOW
};

} // namespace Gxw

#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Glib
{

template <>
class Value<Gxw::TickPosition> : public Glib::Value_Enum<Gxw::TickPosition>
{
public:
  static GType value_type() G_GNUC_CONST;
};

} // namespace Glib
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

namespace Gxw
{


class MeterScale: public Gtk::Widget {
	public:
#ifndef DOXYGEN_SHOULD_SKIP_THIS
  typedef MeterScale CppObjectType;
  typedef MeterScale_Class CppClassType;
  typedef GxMeterScale BaseObjectType;
  typedef GxMeterScaleClass BaseClassType;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

  MeterScale(MeterScale&& src) noexcept;
  MeterScale& operator=(MeterScale&& src) noexcept;

  // noncopyable
  MeterScale(const MeterScale&) = delete;
  MeterScale& operator=(const MeterScale&) = delete;

  ~MeterScale() noexcept override;

#ifndef DOXYGEN_SHOULD_SKIP_THIS

private:
  friend class MeterScale_Class;
  static CppClassType meterscale_class_;

protected:
  explicit MeterScale(const Glib::ConstructParams& construct_params);
  explicit MeterScale(GxMeterScale* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  /// Provides access to the underlying C GObject.
  GxMeterScale*       gobj()       { return reinterpret_cast<GxMeterScale*>(gobject_); }

  /// Provides access to the underlying C GObject.
  const GxMeterScale* gobj() const { return reinterpret_cast<GxMeterScale*>(gobject_); }


public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


private:

	public:
	MeterScale();
	
  void add_mark(double p1, const Glib::ustring& p2);
	
  void clear_marks();
	/** Position of the tick relativ to the tick text.
   *
   * Default value: Tick::RIGHT
   *
   * @return A PropertyProxy that allows you to get or set the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy< TickPosition > property_tick_pos() ;

/** Position of the tick relativ to the tick text.
   *
   * Default value: Tick::RIGHT
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< TickPosition > property_tick_pos() const;


};

} // namespace Gxw


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gxw::MeterScale
   */
  Gxw::MeterScale* wrap(GxMeterScale* object, bool take_copy = false);
} //namespace Glib


#endif /* _GXWMM_METERSCALE_H */

