/*
 * Copyright (C) 2009, 2010 Hermann Meyer, James Warden, Andreas Degert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef __GXW_H__
#define __GXW_H__

#include <gxw/GxTuner.h>
#include <gxw/GxRackTuner.h>
#include <gxw/GxFastMeter.h>
#include <gxw/GxWaveView.h>
#include <gxw/GxRegler.h>
#include <gxw/GxSelector.h>
#include <gxw/GxSwitch.h>
#include <gxw/GxToggleImage.h>
#include <gxw/GxControlParameter.h>
#include <gxw/GxIREdit.h>
#include <gxw/GxRadioButton.h>
#include <gxw/GxWheel.h>
#include <gxw/GxWheelVertical.h>
#include <gxw/GxKnob.h>
#include <gxw/GxBigKnob.h>
#include <gxw/GxMidKnob.h>
#include <gxw/GxSmallKnob.h>
#include <gxw/GxSmallKnobR.h>
#include <gxw/GxHSlider.h>
#include <gxw/GxMiniSlider.h>
#include <gxw/GxVSlider.h>
#include <gxw/GxEQSlider.h>
#include <gxw/GxLevelSlider.h>
#include <gxw/GxPaintBox.h>
#include <gxw/GxMeterScale.h>
#include <gxw/GxValueDisplay.h>
#include <gxw/GxPlayHead.h>
#include <gxw/gxinit.h>

#endif /* __GXW_H__ */
