@import url("gx_head_Guitarix.css");gx-paint-box{-GxPaintBox-icon-set:8;-GxPaintBox-stock-gxhead:"live_wallpaper_grungy_sun.png"}frame,#frame_inversed,frame border,#frame_inversed border{background-color:transparent}frame border,#frame_inversed border{border-color:rgba(50,50,50,0.7);border-style:groove;border-width:1px}
