@import url("gx_head_Guitarix.css");gx-paint-box{-GxPaintBox-icon-set:9;-GxPaintBox-stock-gxhead:"live_wallpaper_grungy_sun_dark.png"}#rackcontainer .effect_title{color:#ffffff}#effect_title{font:condensed 10pt "Roboto";color:#ffffff}#drag_widget .effect_title{color:#ffffff}#rack_label,#Value,#ampbox label,#beffekt_label,#rack_effect_label{color:#ffffff}
